<?php

namespace App\Dto\Output;

use ApiPlatform\Metadata\Get;
use App\Entity\OrganizationalUnit;
use Symfony\Component\Serializer\Annotation\Groups;

#[Get(shortName: 'OrganizationalUnit')]
final class OrganizationalUnitOutput extends AbstractOutput
{
    #[Groups(['organizational-unit:read'])]
    public string $name;

    #[Groups(['organizational-unit:read'])]
    public ?string $comments = null;

    #[Groups(['organizational-unit:read'])]
    public string $type;

    #[Groups(['organizational-unit:read'])]
    public ?self $parent = null;

    #[Groups(['organizational-unit:read'])]
    public string $path;

    #[Groups(['organizational-unit:read'])]
    public ?NetworkSettingsOutput $networkSettings = null;

    #[Groups(['user:read'])]
    public array $clients = [];

    #[Groups(['organizational-unit:read'])]
    public \DateTime $createdAt;

    #[Groups(['organizational-unit:read'])]
    public ?string $createdBy = null;


    public function __construct(OrganizationalUnit $organizationalUnit)
    {
        parent::__construct($organizationalUnit);

        $this->name = $organizationalUnit->getName();
        $this->comments = $organizationalUnit->getComments();
        $this->type = $organizationalUnit->getType();
        $this->networkSettings = $organizationalUnit->getNetworkSettings() ? new NetworkSettingsOutput($organizationalUnit->getNetworkSettings()) : null;
        $this->clients = $organizationalUnit->getClients()->toArray();

        if ($organizationalUnit->getParent()) {
            $this->parent = new self($organizationalUnit->getParent());
        }

        $this->path = $organizationalUnit->getPath();
        $this->createdAt = $organizationalUnit->getCreatedAt();
        $this->createdBy = $organizationalUnit->getCreatedBy();
    }
}